@@ -7,7 +7,10 @@ from typing import (
     Awaitable, Callable, Dict, Iterable, List, Optional, Sequence,
     Set, Tuple, Type)
 
+import abstracts
+
 from aio.run import runner
+from aio.run.checker import abstract
 
 
 _sentinel = object()
@@ -430,7 +433,7 @@ class Checker(runner.Runner):
             self.removed_checks.add(check)
             self.error(
                 check,
-                [f"Check disabled: data download ({task}) failed {e}"])
+                [f"Check disabled, `{task}` failed: {e}"])
 
     async def preload(self) -> None:
         """Async preload data for checks."""
@@ -515,8 +518,7 @@ class Checker(runner.Runner):
         while True:
             if not self.remaining_checks:
                 break
-            check = await self.check_queue.get()
-            if check is _sentinel:
+            if (check := await self.check_queue.get()) is _sentinel:
                 break
             await self._run_check(check)
             self.check_queue.task_done()
@@ -601,11 +603,10 @@ class CheckerSummary(object):
         """Print a summary section."""
         max_display = self.max_problems_of(problem_type, len(problems))
         title = self.problem_title(problem_type, len(problems), max_display)
-        lines = problems[:max_display]
         section = [
             f"{problem_type.upper()} Summary [{check}]{title}",
             "-" * 80]
-        if lines:
+        if lines := problems[:max_display]:
             section += [line.split("\n")[0] for line in lines]
         return "\n".join(section + [""])
 
@@ -626,3 +627,13 @@ class CheckerSummary(object):
             self.checker.log.notice
             if problem_type == "warnings"
             else self.checker.log.error)
+
+
+@abstracts.implementer(abstract.AProblems)
+class Problems:
+
+    def __init__(
+            self,
+            errors: Optional[List[str]] = None,
+            warnings: Optional[List[str]] = None) -> None:
+        abstract.AProblems.__init__(self, errors=errors, warnings=warnings)
